# Step 2: Obtaining the views of health experts and smokers

**Author**: Nele Albers

**Date**: December 2024


This folder is meant to reproduce our findings for the second step of our pipeline in which we obtained the views of health experts and smokers.

This includes reproducing:
  - The self-reported expertise and background of the experts who took part in our repertory grid study.
  - The factors for competencies for quitting smoking from the repertory grid study with experts.
  - The coding of smokers' responses as "competency," "way of doing a preparatory activity," or "unclear" and the computations of Cohen's kappa and Brennan-Prediger kappa that are based on this coding.
  - The factors for competencies for quitting smoking from the repertory grid study with smokers.
  - The clustering of the preparatory activiites for the prediction of the effort and the next values for the user-inquired state features.
  - The responses mapped onto the factors from Table 5.1 in the chapter and Table S2 and Table S3 in the Appendix.


Authored by Nele Albers, Mark A. Neerincx, and Willem-Paul Brinkman.


### Examine results as computed by us

You can inspect the following results as computed/created by us:
   - The self-reported expertise and background of the experts who took part in our repertory grid study: "Data/process_expert_data_for_factor_analysis_output.txt."
   - The factors for competencies for quitting smoking from the repertory grid study with experts: "analysis_expert_competencies.pdf."
   - The coding of smokers' responses by the first coder: "Data/user_responses_for_coding_final_labels_and_explanations_only_anonym_pa_coded.xlsx" and "Data/user_responses_for_coding_final_labels_and_explanations_only_anonym_smoking_coded.xlsx."
   - The coding of smokers' responses by the second coder: "Data/user_responses_for_coding_final_labels_and_explanations_only_anonym_double_coding.xlsx."
   - The number of smokers who were asked to group preparatory activities based on competencies and the number of responses labeled as competency, way of doing a preparatory activity, or uclear by the first coder: "Data/process_user_data_for_factor_analysis_output.txt."
   - The number of responses double-coded by the second coder, Cohen's kappa, and Brennan-Prediger kappa: "Data/calculate_agreement_between_coders_output.txt."
   - The factors for competencies for quitting smoking from the repertory grid study with smokers and the clustering of the preparatory activities: "analysis_user_competencies.pdf" and the generated file "comp_ 5 _activity_clusters_5_ratings.csv."
   - The responses mapped onto the factors from Table 5.1 in the chapter and Table S2 and Table S3 in the Appendix: folder "Labels_and_Explanations_for_Factors," with one file per factor. Each line in the files provides one response with its factor loading, label, and explanation.


### Reproduce analyses yourself

#### Steps to reproduce analyses

You can also reproduce the way we obtained our factors using Docker and R Studio:
1. Make sure you have Docker installed. You can check if you do by running `docker -v`.
2. Navigate to the folder this README-file is in.
3. Now you have 2 options:
      - Build the Docker image via `docker build . -t gbna4/usefulness2024_factor_analysis`, or
      - Pull the Docker image from Dockerhub via `docker pull gbna4/usefulness2024_factor_analysis`.
4. Run the Docker container via `docker run -d -p 8787:8787 -v <path_to_this_directory>:/home/rstudio/analysis -e PASSWORD=<some_password> gbna4/usefulness2024_factor_analysis`.
5. Go to localhost:8787.
6. Login with username 'rstudio' and the password chosen in step 4.
7. Navigate to the "analysis"-folder in R Studio.
9. Now you can reproduce the results via the .Rmd-files "analysis_expert_competencies.Rmd" and "analysis_user_competencies.Rmd."


You can further run the python-files in the "Data"-folder to reproduce our preprocessing steps. Running these files requires the packages `pandas` and `sklearn`.


#### Knitting R markdown

If you just want to knit an analysis file to a pdf-file, take the following steps:
1. Make sure you have Docker installed.
2. Navigate to the folder this README-file is in.
3. Now you have 2 options:
      - Build the Docker image via `docker build . -t gbna4/usefulness2024_factor_analysis`, or
      - Pull the Docker image from Dockerhub via `docker pull gbna4/usefulness2024_factor_analysis`.
4. Run an interactive session with the Docker container via `docker run -it -v <path_to_directory_of_this_README_file>:/home/rstudio/analysis gbna4/usefulness2024_factor_analysis /bin/bash`.
5. In the interactive session, type `cd /home/rstudio/analysis` to navigate to the analysis-folder.
6. Start an R session via `R`.
7. Import rmarkdown via `library('rmarkdown')`.
8. Knit an R markdown file via `render("<analysis_file>.Rmd", output_file = "<desired_output_file_name>.pdf")`.


### Files and folders

This folder contains the following folders and files:

   - Data:
      - all_competency_ratings_transposed.csv: input data for the exploratory factor analysis with smokers, created using the file "process_user_data_for_factor_analysis.py."
	  - all_expert_competency_ratings_transposed.csv: input data for the exploratory factor analysis with experts, created using the file "process_expert_data_for_factor_analysis.py."
	  - calculate_agreement_between_coders.py: file to compute the agreement between the two coders for the responses from smokers.
	  - calculate_agreement_between_coders_output.txt: output of the above file.
	  - Expert_Competencies_Final_Qualtrics_Export_2022_12_22_anonym.xlsx: anonymized data from study with experts.
	  - Expert_Competencies_Final_Qualtrics_Export_2022_12_22_data_explanation.xlsx: explanation of the columns in the data file above.
	  - process_expert_data_for_factor_analysis.py: file that preprocesses the expert data for the exploratory factor analysis.
	  - process_expert_data_for_factor_analysis_output.txt: output of the above file (e.g., background of experts).
	  - process_user_data_for_factor_analysis.py: file that preprocesses the smoker data for the exploratory factor analysis.
	  - process_user_data_for_factor_analysis_output.txt: output of the above file (e.g., number of responses coded as "competency" by the first coder).
	  - user_responses_for_coding_final_full_dataframe_anonym.csv: anonymized data from the study with smokers.
	  - user_responses_for_coding_final_full_dataframe_data_explanation.xlsx: explanation of the columns in the data file above.
	  - user_responses_for_coding_final_labels_and_explanations_only_anonym_double_coding.xlsx: codes assigned by the second coder.
	  - user_responses_for_coding_final_labels_and_explanations_only_anonym_pa_coded.xlsx: codes assigned by the first coder to preparatory activities that are about physical activity.
	  - user_responses_for_coding_final_labels_and_explanations_only_anonym_smoking_coded.xlsx: codes assigned by the first coder to prepratory activities that are purely about smoking.
   - Labels_and_Explanations_for_Factors: contains the responses mapped onto the final factors for the two exploratory factor analyses. There is one file per factor.
   - analysis_expert_competencies.pdf: results of the repertory grid study with experts as computed by us.
   - analysis_expert_competencies.Rmd: file to allow you to reproduce the above results.
   - analysis_user_competencies.pdf: results of the repertory grid study with smokers as well as the preparatory activity clustering as computed by us.
   - analysis_user_competencies.Rmd: file to allow you to reproduce the above results.
   - comp_ 5 activity_clusters_5_ratings.csv: cluster per preparatory activity used for the prediction of efforts and next values of user-inquired state features.
   - comp_3factors_df_loadings_experts.csv: contains the weights from the factor analysis with experts, later needed to compute the contributions of the preparatory activities to the six expert competencies.
   - comp_3factors_df_ratings_experts.csv: contains the ratings given by experts, later needed to compute the contributions of the preparatory activities to the six expert competencies.
   - Dockerfile: file to allow you to build the Docker image yourself.
   - README.md/README.pdf: this README-file.
