# Comparing Smoking Frequency, Weekly Exercise, and Quitter Self-Identity Over Time


**Author**: Nele Albers

**Date**: December 2024


This file is meant to allow you to reproduce our analysis of the changes in smoking frequency, weekly exercise, and quitter self-identity between the prescreening questionnaire on the one hand and the post-questionnaire and follow-up questionnaire on the other hand. In the chapter, the results are reported in "Step 5: Training the model - Study."


### Examine Results as Computed by Us

To examine the output of the analyses obtained by us, refer to:
   - the file "comparison_prefollowup.pdf" for the comparison between the prescreening questionnaire and the follow-up questionnaire, and
   - the file "comparison_prepost.pdf" for the comparison between the prescreening questionnaire and the post-questionnaire.


### Reproduce Analyses Yourself

This section is to explain how you can run the analyses yourself.


#### Requirements

You need to have Docker installed.


#### Steps to Reproduce Analyses

The reproduction of our analyses is based on Docker and R Studio. Take the following steps:
1. Make sure you have Docker installed. You can check if you do by running `docker -v`.
2. Navigate to the folder this README-file is in.
3. Now you have 2 options:
      - Build the Docker image via `docker build . -t gbna4/usefulness2024_r_rethinking`, or
      - Pull the Docker image from Dockerhub via `docker pull gbna4/usefulness2024_r_rethinking`.
4. Run the Docker container via `docker run -d -p 8787:8787 -v <path_to_this_directory>:/home/rstudio/analysis -e PASSWORD=<some_password> gbna4/usefulness2024_r_rethinking`.
5. Go to localhost:8787.
6. Login with username 'rstudio' and the password chosen in step 4.
7. Navigate to the "analysis"-folder in R Studio.
9. Now you can reproduce the analysis results using the files "comparison_prefollowup.Rmd" and "comparison_prepost.Rmd."


#### Knitting R Markdown

If you just want to knit an analysis file to a pdf-file, take the following steps:
1. Make sure you have Docker installed.
2. Navigate to the folder this README-file is in.
3. Now you have 2 options:
      - Build the Docker image via `docker build . -t gbna4/usefulness2024_r_rethinking`. 
      - Pull the Docker image from Dockerhub via `docker pull gbna4/usefulness2024_r_rethinking`.
4. Run an interactive session with the Docker container via `docker run -it -v <path_to_directory_of_this_README_file>:/home/rstudio/analysis gbna4/usefulness2024_r_rethinking /bin/bash`.
5. In the interactive session, type `cd /home/rstudio/analysis` to navigate to the analysis-folder.
6. Start an R session via `R`.
7. Import rmarkdown via `library('rmarkdown')`.
8. Knit an R markdown file via `render("<analysis_file>.Rmd", output_file = "<desired_output_file_name>.pdf")`.


### Explanation of Folders and Files

This directory contains the following files and folders:
   - Data:
      - prefu_preprocessed.csv: preprocessed data for the comparison between the prescreening questionnaire and the follow-up questionnaire.
	  - prepost_preprocessed.csv: preprocessed data for the comparison between the prescreening questionnaire and the post-questionnaire.
   - comparison_prefollowup.pdf: results of the comparison between the prescreening questionnaire and the follow-up questionnaire obtained by us.
   - comparison_prefollowup.Rmd: Rmd-file to allow you to reproduce our results from the above file.
   - comparison_prepost.pdf: results of the comparison between the prescreening questionnaire and the post-questionnaire obtained by us.
   - comparison_prepost.Rmd: Rmd-file to allow you to reproduce our results from the above file.
   - Dockerfile: file to allow you to build the Docker image yourself.
   - README.md/README.pdf: this README-file.
