# -*- coding: utf-8 -*-
"""
This file shows how we anonymized the data from the conversational sessions.
Since we cannot provide the non-anonymized data, you cannot run this script yourself.

Required files:
    - Database_Exports/sessiondata_202308280831.csv
    - additional_sessiondata_from_events_db.xlsx
    - anonymization_key.xlsx
    
Created files:
    - sessionsdata_anonym.csv

Author: Nele Albers
Date: September 2023
"""

import pandas as pd


if __name__ == "__main__":

    # Load sessions data
    df_session = pd.read_csv("Database_Exports/sessiondata_202308280831.csv")
    # Data not saved to sessionsdata table but manually extracted from events db
    df_session_extra = pd.read_excel("additional_sessiondata_from_events_db.xlsx")

    df_session_merged = pd.concat([df_session, df_session_extra])


    # Load anonymization key
    df_key = pd.read_excel("anonymization_key.xlsx")


    # Anonymize sessions data
    df_session_merged = pd.merge(df_session_merged, df_key, left_on = "prolific_id",
                                 right_on = "PROLIFIC_PID")
    df_session_merged = df_session_merged.drop(columns=["prolific_id", "PROLIFIC_PID"])


    # Remove the data that we do not need for this paper (i.e., activity experiences and mood)
    df_session_merged = df_session_merged[~df_session_merged["response_type"].isin(["activity_experience_slot",
                                                                                    "activity_experience_mod_slot",
                                                                                    "mood"])]

    # Remove columns we do not need/cannot publish
    df_session_merged = df_session_merged.drop(columns=["time", 'idx'])


    # Save anonymized data
    df_session_merged.to_csv("sessionsdata_anonym.csv", index=False)
