"""
This file shows how we anonymized the data from the post-questionnaire
Since we cannot provide the non-anonymized data, you cannot run this script yourself.

Required files:
    - anonymization_key.xlsx
    - qualtrics_post_questionnaire_final_2023_08_30.csv
    
Created files:
    - clean_and_anonymize_postquestionnaire_data_output.txt
    - postquestionnaire_anonym.csv

Author: Nele Albers
Date: January 2024
"""

import pandas as pd


if __name__ == "__main__":

    # Load post-questionnaire data
    df_post = pd.read_csv("qualtrics_post_questionnaire_final_2023_08_30.csv")


    # Load anonymization key
    df_key = pd.read_excel("anonymization_key.xlsx")


    # Anonymize data
    df_post = pd.merge(df_post, df_key, on = "PROLIFIC_PID")
    df_post = df_post.drop(columns=["PROLIFIC_PID", "Prolific_ID"])


    # Remove columns we do not need/cannot publish
    df_post = df_post.drop(columns=["StartDate", "EndDate", "Status",
                                    "Progress", "Duration (in seconds)",
                                    "RecordedDate", "ResponseId",
                                    "UserLanguage", 
                                    "DistributionChannel",
                                    "Q_RecaptchaScore",
                                    "Activity_experience", 
                                    "Effort_1",
                                    "Godin_exercise_11", 
                                    "Godin_exercise_9",
                                    "Godin_exercise_8",
                                    "Last_smoke"])


    # Remove data from people who did not finish the questionnaire
    length_before = len(df_post)
    df_post = df_post.dropna(subset=["AC2"])
    length_after = len(df_post)
    print("Number of incomplete submissions removed:", length_before - length_after)
    with open("clean_and_anonymize_postquestionnaire_data_output.txt", 'w') as f:
        f.write("Number of incomplete submissions removed: " + str(length_before - length_after) + "\n")


    # Remove data from people failing more than 1 attention check
    length_before = len(df_post)
    df_post = df_post[(df_post["AC2"].isin(["color", "colour", "Color"])) | (df_post["Quitter_Self_Identit_4"].isin(["Disagree strongly", "Disagree"]))]
    df_post = df_post.reset_index(drop=True)
    length_after = len(df_post)
    print("Number of submissions removed for failing 2 attention checks:", length_before - length_after)
    print("Remaining number of submissions:", length_after)
    with open("clean_and_anonymize_postquestionnaire_data_output.txt", 'a') as f:
        f.write("Number of submissions removed for failing 2 attention checks: " + str(length_before - length_after) + "\n")
        f.write("Remaining number of submissions: " + str(length_after))


    # Save anonymized data
    df_post.to_csv("postquestionnaire_anonym.csv", index=False)
